@@ -279,3 +279,10 @@ class UserContribution(Document):
     repository = StringField()
     file = StringField()
     line_history = EmbeddedDocumentListField(LineHistory)
+
+class FileCommitHistory(Document):
+    """File line commit history"""
+    organization = StringField()
+    repository = StringField()
+    file = StringField()
+    commits = ListField(StringField())
